/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ;
typedef struct tyObject_Table__Os4it9bmHnOQtsd5CqH09aRQ tyObject_Table__Os4it9bmHnOQtsd5CqH09aRQ;
typedef struct tySequence__hLW2w9a9bDM1AHB8BIrU3BYw tySequence__hLW2w9a9bDM1AHB8BIrU3BYw;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw;
typedef struct tyObject_Table__JrI9bTpOVccKpiJXKOskjFg tyObject_Table__JrI9bTpOVccKpiJXKOskjFg;
typedef struct tySequence__YuKuU17u5ApAIki23DK9bJw tySequence__YuKuU17u5ApAIki23DK9bJw;
typedef struct tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyTuple__YGgHblKlCINajXDZno8UTQ tyTuple__YGgHblKlCINajXDZno8UTQ;
typedef struct tyTuple__Wymbvuvlf49clEgp9bKoFN9bw tyTuple__Wymbvuvlf49clEgp9bKoFN9bw;

/* section: NIM_merge_TYPES */
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
typedef NU8 tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
struct tyObject_Table__Os4it9bmHnOQtsd5CqH09aRQ {
tySequence__hLW2w9a9bDM1AHB8BIrU3BYw* data;
NI counter;
};
struct tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ {
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg processed;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg capturedVars;
tyObject_Table__Os4it9bmHnOQtsd5CqH09aRQ ownerToType;
NIM_BOOL somethingToDo;
tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph;
};
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
typedef NU64 tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NimStringDesc* tyArray__24KAM9afIUgUaqBaEBB6r9bg[3];
typedef NU8 tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw;
typedef NU8 tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ;
struct TNimNode {
tyEnum_TNimNodeKind__unfNsxrcATrufDZmpBq4HQ kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_Table__JrI9bTpOVccKpiJXKOskjFg {
tySequence__YuKuU17u5ApAIki23DK9bJw* data;
NI counter;
};
struct tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw {
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg processed;
tyObject_Table__JrI9bTpOVccKpiJXKOskjFg envVars;
NI inContainer;
tyObject_Table__JrI9bTpOVccKpiJXKOskjFg unownedEnvVars;
};
typedef tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* tyArray__AB6yfoUgfWM2NtGe9bzkCmw[2];
typedef NU8 tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TSymKind__uwRDzlpaGW5WJzgBn4R8Eg;
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};
struct tyTuple__YGgHblKlCINajXDZno8UTQ {
NI Field0;
NI Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__Wymbvuvlf49clEgp9bKoFN9bw {
NI Field0;
NI Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__hLW2w9a9bDM1AHB8BIrU3BYw {
  TGenericSeq Sup;
  tyTuple__YGgHblKlCINajXDZno8UTQ data[SEQ_DECL_SIZE];
};
struct tySequence__YuKuU17u5ApAIki23DK9bJw {
  TGenericSeq Sup;
  tyTuple__Wymbvuvlf49clEgp9bKoFN9bw data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
static N_INLINE(NIM_BOOL, interestingVar__BNaKs79aGny5MAVCr9a8Kurwlambdalifting)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isGenericRoutine__uUQONnU7icBs9bdkKqJVqhA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, propagateClosure__wDpUfPhajvUnUXFZvsXXaw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* start, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* last);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size);
N_LIB_PRIVATE N_NIMCALL(void, initDetectionPass__P5KW8HQhQCFeBR8BnZtcJw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* Result);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void, initIntSet__n8oDZMn19bEdodSnrBQB9a1Q)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* Result);
N_LIB_PRIVATE N_NIMCALL(void, initTable__a9bC7nkiLU3lFTLZqMubj5Q)(NI initialSize, tyObject_Table__Os4it9bmHnOQtsd5CqH09aRQ* Result);
N_LIB_PRIVATE N_NIMCALL(void, incl__jENnK9c9bPE73pKmo2vYjpqg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(void, detectCapturedVars__knMMYMrxMvpPAdvZhU1Tjg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* c);
N_LIB_PRIVATE N_NIMCALL(void, addClosureParam__lKI5vTqvn65UP6LyU15ZDg)(tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getEnvParam__0hs55xLsSn1sbFSXWwel1A)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* routine);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, lastSon__UPSW0jLTX5qJL51YMUAHgw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getEnvTypeForOwner__JBqxLzBtZb2sydgcQO6g2w)(tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getOrDefault__9bQKf8dFvOTPFC2tZLVBE7A)(tyObject_Table__Os4it9bmHnOQtsd5CqH09aRQ t, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newType__SNqpa06pdVCLFFBR28119aQ)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, createEnvObj__4Wga9cCREe0sfPDxyRcvR6A)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, createObj__vpIcmDdKH7ed0dcs37b1GQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NIM_BOOL final);
N_LIB_PRIVATE N_NIMCALL(void, rawAddField__5lAtboIt7Cs3LrzdvDm30A)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, createStateField__9coyF0wpG1VqYcJq7Zk1fgQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* iter);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSym__IXbidcxhXTQGZY9abN63Cxg)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*, getIdent__9coBOmdXN09be4rJvXK6fQGQ)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* ic, NimStringDesc* identifier);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, createClosureIterStateType__YeSbRn4y243XNGGtCU6V6g)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* iter);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__vokyXY9cZDshCSxFKChhG9bg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, add__P8dDSotTW25BkfbyspojGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntNode__zcNs9blLGYB6i9aGKob9bpzRw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, NI64 intVal);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, nilOrSysInt__VXHJ4pNirNxlb1PKZUnJQw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g);
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___MQp6geYbWilpbmJT3tnncQ)(tyObject_Table__Os4it9bmHnOQtsd5CqH09aRQ* t, NI key, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* val);
N_LIB_PRIVATE N_NIMCALL(void, addHiddenParam__7WLlxVbZQIFaud5CB3qY3g)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* routine, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__I2DV2TmmOysY1ZEGW19b9bRg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInnerProc__tZttBPVF68vMBBdix9bG4sQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, transformBody__ocxOgPRHWfivNZELIhOv7w)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc, NIM_BOOL cache);
static N_INLINE(NIM_BOOL, interestingIterVar__BNaKs79aGny5MAVCr9a8Kurw_2lambdalifting)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getHiddenParam__EE7nw3Cq0S1IZY9aGfs1AtA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* routine);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(void, addField__hrnJBvN8tSy4gj6R5QDcYw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache);
N_LIB_PRIVATE N_NIMCALL(void, markAsClosure__pewMCU9aolg9bl79a4WiPZ4HA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
static N_INLINE(NIM_BOOL, illegalCapture__BNaKs79aGny5MAVCr9a8Kurw_3lambdalifting)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__QlvraUan7WbHowhAbvDvdA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___aQsiZUvE4SFfnWyKx1JgKA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(void, createUpField__vlqsfLq9b9cUFFP9cvYdZU3LA)(tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* dest, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* dep, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__jkXTnxDf8MX1Pmks3s0XxA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, NimStringDesc* symbol);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getEnvTypeForOwnerUp__JBqxLzBtZb2sydgcQO6g2w_2)(tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* field);
N_LIB_PRIVATE N_NIMCALL(void, initLiftingPass__mkHIcVQZdXl9cGPFvTV4ZWA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw* Result);
N_LIB_PRIVATE N_NIMCALL(void, initTable__TJKMxrEPQUpx86MsTl1C3A)(NI initialSize, tyObject_Table__JrI9bTpOVccKpiJXKOskjFg* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, liftCapturedVars__1JM0Ep6665B6crlfoxbCuQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* d, tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getOrDefault__OX9anFuDn9bfK9aeoL9blUUBvw)(tyObject_Table__JrI9bTpOVccKpiJXKOskjFg t, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newTree__FpOm4fidh9bWdkMa1BMRJkQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** children, NI childrenLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, rawClosureCreation__uYj8l4iSUGRUAThDXmR3AQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* d, tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, setupEnvVar__uYj8l4iSUGRUAThDXmR3AQ_2)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* d, tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newEnvVar__eDqCayFpoOQA1G9cygMQKxA)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, asOwnedRef__Myowsqh71MOvPLm9bgYQ50A)(tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___tMEyAvlcC3r82WGaTaSYrQ)(tyObject_Table__JrI9bTpOVccKpiJXKOskjFg* t, NI key, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* val);
N_LIB_PRIVATE N_NIMCALL(void, addVar__qOCBdprWtK4hxer73SEdQA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**, X5BX5D___X7HRLXyMghOAScJitThqsw)(tyObject_Table__JrI9bTpOVccKpiJXKOskjFg* t, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newCall__8664d9ayvIMAWB9cM5EcHP7Q)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getSysSym__9bvw79ck1FDiWpnBYh88rEfw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, copyTree__Dsjo9bte8vGxzhtcSrsTyiQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newAsgnStmt__0EDAdA9aH20kXbo0qceLIoQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NI children);
N_LIB_PRIVATE N_NIMCALL(void, createTypeBoundOpsLL__zNEHc9bDojTsulmL716BbGw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* refType, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(void, createTypeBoundOps__HRpOwQj0TjFM8eZsKc7jlw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* orig, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__R6uRTGpl30Ofaw4Ni3vawA)(tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg* s, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, indirectAccess__fh4Yh9bIIARGtqRFUnv8SDA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* b, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getUpViaParam__5aTkGMxbYzGq8tgBuEAcvw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, rawIndirectAccess__8aXgrGQvaIrhwp6o9cuBYoA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, finishClosureCreation__yhHyVa9bbyRc86LofEPTIBw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* d, tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* res);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, X5BX5D___OX9anFuDn9bfK9aeoL9blUUBvw_2)(tyObject_Table__JrI9bTpOVccKpiJXKOskjFg t, NI key);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, symToClosure__1JM0Ep6665B6crlfoxbCuQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* d, tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, makeClosure__fa9aZDXQ04CAodm0trAX6LA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* env, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, skipConv__BH9abOhPX8pH0DnEWlRxmlw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, closureCreationForIter__aBUE4CjNZyw9ch83XM4bSVA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* iter, tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* d, tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, addUniqueField__CLL3aqLIY5XbgRQPQDI3cw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, accessViaEnvParam__8CYqf1nXlpBtnWvyO6vrCw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getFieldFromObj__a9b9aDcfE1em9bBkDPbo9cqoSg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, accessViaEnvVar__1JM0Ep6665B6crlfoxbCuQ_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* d, tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw* c);
static N_INLINE(NIM_BOOL, liftingHarmful__VHxic9aDgFru4d09c6I7A1HQlambdalifting)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw)(NI64 intVal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(void, transitionToLet__EEixHgS5VK63cVXrrMe6Tw_2)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s);
N_LIB_PRIVATE N_NIMCALL(void, transitionRoutineSymKind__IAW6i9bfWpSsueZudnBZzHQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyEnum_TSymKind__uwRDzlpaGW5WJzgBn4R8Eg kind);

/* section: NIM_merge_DATA */
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_2, ":envP", 5);
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_3, ":state", 6);
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_4, "internal error: inconsistent environment type", 45);
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_6, "/home/runner/work/nightlies/nightlies/nim/compiler/lambdaliftin"
"g.nim", 68);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__PI7oJkFuxeeTWjPTjlNxqg_5 = {((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_6),
((NI) 418),
((NI) 14)}
;
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_7, "internal error: could not find env param for ", 45);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__PI7oJkFuxeeTWjPTjlNxqg_8 = {((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_6),
((NI) 178),
((NI) 14)}
;
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_9, "\'$1\' is of type <$2> which cannot be captured as it would viola"
"te memory safety, declared here: $3; using \'-d:nimWorkaround1444"
"7\' helps in some cases", 149);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__PI7oJkFuxeeTWjPTjlNxqg_10 = {((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_6),
((NI) 292),
((NI) 14)}
;
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_11, "illegal capture \'$1\' because \'$2\' has the calling convention: <"
"$3>", 66);
extern TNimType NTI__yjAJ8w0h1PBaSwSGJ3P7IA_;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__PI7oJkFuxeeTWjPTjlNxqg_12 = {((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_6),
((NI) 297),
((NI) 14)}
;
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_13, "nimCycleBreaker", 15);
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_14, "internal error: invalid up reference computed", 45);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__PI7oJkFuxeeTWjPTjlNxqg_15 = {((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_6),
((NI) 363),
((NI) 14)}
;
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_16, ":up", 3);
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_17, "internal error: up references do not agree", 42);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__PI7oJkFuxeeTWjPTjlNxqg_18 = {((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_6),
((NI) 369),
((NI) 16)}
;
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_19, "internal error: could not determine closure type", 48);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__PI7oJkFuxeeTWjPTjlNxqg_20 = {((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_6),
((NI) 559),
((NI) 17)}
;
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_21, ":env", 4);
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_22, ":envAlt", 7);
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_23, "internalNew", 11);
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_24, "could not find up reference for closure iter", 44);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__PI7oJkFuxeeTWjPTjlNxqg_25 = {((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_6),
((NI) 574),
((NI) 16)}
;
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_26, "internal error: cannot create up reference", 42);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__PI7oJkFuxeeTWjPTjlNxqg_27 = {((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_6),
((NI) 628),
((NI) 16)}
;
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_28, "internal error: taking closure of closure", 41);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__PI7oJkFuxeeTWjPTjlNxqg_29 = {((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_6),
((NI) 219),
((NI) 16)}
;
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_30, "internal error: cannot create up reference for iter", 51);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__PI7oJkFuxeeTWjPTjlNxqg_31 = {((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_6),
((NI) 669),
((NI) 16)}
;
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_32, "internal error: no environment found", 36);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__PI7oJkFuxeeTWjPTjlNxqg_33 = {((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_6),
((NI) 714),
((NI) 18)}
;
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_34, "internal error: environment misses: ", 36);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__PI7oJkFuxeeTWjPTjlNxqg_35 = {((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_6),
((NI) 535),
((NI) 12)}
;
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_36, "internal error: not part of closure object type", 47);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__PI7oJkFuxeeTWjPTjlNxqg_37 = {((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_6),
((NI) 682),
((NI) 14)}
;
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_38, "ignored invalid for loop", 24);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__PI7oJkFuxeeTWjPTjlNxqg_39 = {((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_6),
((NI) 920),
((NI) 14)}
;
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_40, "internal error: cannot generate fresh variable", 46);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__PI7oJkFuxeeTWjPTjlNxqg_41 = {((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_6),
((NI) 284),
((NI) 14)}
;
STRING_LITERAL(TM__PI7oJkFuxeeTWjPTjlNxqg_42, ":result", 7);

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_INLINE(NIM_BOOL, interestingVar__BNaKs79aGny5MAVCr9a8Kurwlambdalifting)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((2100008 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	if (!(T2_)) goto LA3_;
	T2_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3))&63U)))!=0));
	LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = !(((IL64(1152921504606847232) &((NU64)1<<((NU)((*(*s).typ).kind)&63U)))!=0));
	LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, propagateClosure__wDpUfPhajvUnUXFZvsXXaw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* start, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* last) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* o;
	o = start;
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = !((o == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
			if (!(T3_)) goto LA4_;
			T3_ = !(((*o).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)));
			LA4_: ;
			if (!T3_) goto LA2;
			{
				if (!(o == last)) goto LA7_;
				goto LA1;
			}
			LA7_: ;
			(*(*o).typ).callConv = ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9);
			o = skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3(o);
		} LA2: ;
	} LA1: ;
}
N_LIB_PRIVATE N_NIMCALL(void, semCaptureSym__h6aJJZj4uWFwM8eXN4VDAw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = interestingVar__BNaKs79aGny5MAVCr9a8Kurwlambdalifting(s);
		if (!(T3_)) goto LA4_;
		T3_ = !(((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11)));
		LA4_: ;
		if (!T3_) goto LA5_;
		{
			NIM_BOOL T9_;
			NIM_BOOL T11_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* o;
			T9_ = (NIM_BOOL)0;
			T9_ = !(((*owner).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T9_)) goto LA10_;
			T11_ = (NIM_BOOL)0;
			T11_ = isGenericRoutine__uUQONnU7icBs9bdkKqJVqhA(owner);
			T9_ = !(T11_);
			LA10_: ;
			if (!T9_) goto LA12_;
			o = skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3(owner);
			{
				while (1) {
					NIM_BOOL T16_;
					T16_ = (NIM_BOOL)0;
					T16_ = !((o == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
					if (!(T16_)) goto LA17_;
					T16_ = !(((*o).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)));
					LA17_: ;
					if (!T16_) goto LA15;
					{
						if (!((*s).owner == o)) goto LA20_;
						{
							NIM_BOOL T24_;
							NIM_BOOL T25_;
							NIM_BOOL T28_;
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T32_;
							T24_ = (NIM_BOOL)0;
							T25_ = (NIM_BOOL)0;
							T25_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
							if (T25_) goto LA26_;
							T25_ = ((*owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
							LA26_: ;
							T24_ = T25_;
							if (T24_) goto LA27_;
							T28_ = (NIM_BOOL)0;
							T28_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 0));
							if (!(T28_)) goto LA29_;
							T28_ = !((((*(*owner).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 42))&63U)))!=0));
							LA29_: ;
							T24_ = T28_;
							LA27_: ;
							if (!T24_) goto LA30_;
							(*(*owner).typ).callConv = ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9);
							T32_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
							T32_ = skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3(owner);
							propagateClosure__wDpUfPhajvUnUXFZvsXXaw(T32_, (*s).owner);
						}
						goto LA22_;
						LA30_: ;
						{
						}
						LA22_: ;
					}
					LA20_: ;
					o = skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3(o);
				} LA15: ;
			}
		}
		LA12_: ;
	}
	LA5_: ;
}
static N_INLINE(void, nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__zxfKBYntu9cBapkhrCOk1fgmemory(p, ((int) 0), size);
}
N_LIB_PRIVATE N_NIMCALL(void, initDetectionPass__P5KW8HQhQCFeBR8BnZtcJw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* Result) {
	NI T1_;
	NI T2_;
	(*Result).processed.elems = 0;
	(*Result).processed.counter = 0;
	(*Result).processed.max = 0;
	unsureAsgnRef((void**)&(*Result).processed.head, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).processed.data, NIM_NIL);
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < 34; T1_++) {
	(*Result).processed.a[T1_] = 0;
	}
	(*Result).capturedVars.elems = 0;
	(*Result).capturedVars.counter = 0;
	(*Result).capturedVars.max = 0;
	unsureAsgnRef((void**)&(*Result).capturedVars.head, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).capturedVars.data, NIM_NIL);
	T2_ = (NI)0;
	for (T2_ = 0; T2_ < 34; T2_++) {
	(*Result).capturedVars.a[T2_] = 0;
	}
	unsureAsgnRef((void**)&(*Result).ownerToType.data, NIM_NIL);
	(*Result).ownerToType.counter = 0;
	(*Result).somethingToDo = 0;
	unsureAsgnRef((void**)&(*Result).graph, NIM_NIL);
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&(*Result).processed));
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&(*Result).capturedVars));
	initTable__a9bC7nkiLU3lFTLZqMubj5Q(((NI) 32), (&(*Result).ownerToType));
	incl__jENnK9c9bPE73pKmo2vYjpqg((&(*Result).processed), (*fn).Sup.id);
	unsureAsgnRef((void**) (&(*Result).graph), g);
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__9bGgqEk7RXXl6eqM9c1HdELAsystem(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getEnvParam__0hs55xLsSn1sbFSXWwel1A)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* routine) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* params;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* hidden;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	params = (*(*routine).ast)._kind_6.sons->data[((NI) 3)];
	hidden = lastSon__UPSW0jLTX5qJL51YMUAHgw(params);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*hidden).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T3_)) goto LA4_;
		T3_ = eqStrings((*(*(*hidden)._kind_4.sym).name).s, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_2));
		LA4_: ;
		if (!T3_) goto LA5_;
		result = (*hidden)._kind_4.sym;
	}
	LA5_: ;
	return result;
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, createClosureIterStateType__YeSbRn4y243XNGGtCU6V6g)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* iter) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T2_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* intType;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	n = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 44), (*iter).info);
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), IL64(-1));
	add__P8dDSotTW25BkfbyspojGg(n, T1_);
	T2_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T2_ = newIntNode__zcNs9blLGYB6i9aGKob9bpzRw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 6), IL64(0));
	add__P8dDSotTW25BkfbyspojGg(n, T2_);
	result = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 20), iter);
	asgnRef((void**) (&(*result).n), n);
	intType = nilOrSysInt__VXHJ4pNirNxlb1PKZUnJQw(g);
	{
		if (!(intType == 0)) goto LA5_;
		intType = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31), iter);
	}
	LA5_: ;
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, intType, NIM_TRUE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, createStateField__9coyF0wpG1VqYcJq7Zk1fgQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* iter) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T1_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T1_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*g).cache, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_3));
	result = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19), T1_, iter, (*iter).info, 0);
	asgnRef((void**) (&(*result).typ), createClosureIterStateType__YeSbRn4y243XNGGtCU6V6g(g, iter));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, createEnvObj__4Wga9cCREe0sfPDxyRcvR6A)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = createObj__vpIcmDdKH7ed0dcs37b1GQ(g, owner, info, NIM_FALSE);
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = createStateField__9coyF0wpG1VqYcJq7Zk1fgQ(g, owner);
	rawAddField__5lAtboIt7Cs3LrzdvDm30A(result, T1_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getEnvTypeForOwner__JBqxLzBtZb2sydgcQO6g2w)(tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	result = getOrDefault__9bQKf8dFvOTPFC2tZLVBE7A((*c).ownerToType, (*owner).Sup.id);
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj;
		if (!(result == 0)) goto LA3_;
		result = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 22), owner);
		obj = createEnvObj__4Wga9cCREe0sfPDxyRcvR6A((*c).graph, owner, info);
		rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, obj, NIM_TRUE);
		X5BX5Deq___MQp6geYbWilpbmJT3tnncQ((&(*c).ownerToType), (*owner).Sup.id, result);
	}
	LA3_: ;
	return result;
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addHiddenParam__7WLlxVbZQIFaud5CB3qY3g)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* routine, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* param) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* params;
	NI T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T2_;
	params = (*(*routine).ast)._kind_6.sons->data[((NI) 3)];
	T1_ = (NI)0;
	T1_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*routine).typ).n);
	(*param).position = (NI)(T1_ - ((NI) 1));
	T2_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T2_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(param);
	add__P8dDSotTW25BkfbyspojGg(params, T2_);
}
N_LIB_PRIVATE N_NIMCALL(void, addClosureParam__lKI5vTqvn65UP6LyU15ZDg)(tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* cp;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	cp = getEnvParam__0hs55xLsSn1sbFSXWwel1A(fn);
	{
		if (!((*fn).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15))) goto LA3_;
		owner = fn;
	}
	goto LA1_;
	LA3_: ;
	{
		owner = skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3(fn);
	}
	LA1_: ;
	t = getEnvTypeForOwner__JBqxLzBtZb2sydgcQO6g2w(c, owner, info);
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T10_;
		if (!(cp == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA8_;
		T10_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T10_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*(*c).graph).cache, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_2));
		cp = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3), T10_, fn, (*fn).info, 0);
		(*cp).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 2)) & 63);
		asgnRef((void**) (&(*cp).typ), t);
		addHiddenParam__7WLlxVbZQIFaud5CB3qY3g(fn, cp);
	}
	goto LA6_;
	LA8_: ;
	{
		NIM_BOOL T12_;
		T12_ = (NIM_BOOL)0;
		T12_ = !(((*cp).typ == t));
		if (!(T12_)) goto LA13_;
		T12_ = !(((*fn).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15)));
		LA13_: ;
		if (!T12_) goto LA14_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*fn).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_4), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__PI7oJkFuxeeTWjPTjlNxqg_5, NIM_FALSE);
	}
	goto LA6_;
	LA14_: ;
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInnerProc__tZttBPVF68vMBBdix9bG4sQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((126976 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
		if (!(T3_)) goto LA4_;
		T3_ = ((*s).magic == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 0));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T7_ = skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3(s);
		result = ((520192 &((NU32)1<<((NU)((*T7_).kind)&31U)))!=0);
	}
	LA5_: ;
	return result;
}
static N_INLINE(NIM_BOOL, interestingIterVar__BNaKs79aGny5MAVCr9a8Kurw_2lambdalifting)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((2100000 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
	if (!(T1_)) goto LA2_;
	T1_ = !((((*s).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 3))&63U)))!=0));
	LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__i80o3k0SgEI5gTRCzYdyWAsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getHiddenParam__EE7nw3Cq0S1IZY9aGfs1AtA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* routine) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* params;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* hidden;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	params = (*(*routine).ast)._kind_6.sons->data[((NI) 3)];
	hidden = lastSon__UPSW0jLTX5qJL51YMUAHgw(params);
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*hidden).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T4_)) goto LA5_;
		T4_ = ((*(*hidden)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3));
		LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T3_ = eqStrings((*(*(*hidden)._kind_4.sym).name).s, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_2));
		LA6_: ;
		if (!T3_) goto LA7_;
		result = (*hidden)._kind_4.sym;
	}
	goto LA1_;
	LA7_: ;
	{
		NimStringDesc* T10_;
		T10_ = (NimStringDesc*)0;
		T10_ = rawNewString(((*(*routine).name).s ? (*(*routine).name).s->Sup.len : 0) + 45);
appendString(T10_, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_7));
appendString(T10_, (*(*routine).name).s);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*routine).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T10_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__PI7oJkFuxeeTWjPTjlNxqg_8, NIM_FALSE);
		result = routine;
	}
	LA1_: ;
	return result;
}
static N_INLINE(NIM_BOOL, illegalCapture__BNaKs79aGny5MAVCr9a8Kurw_3lambdalifting)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T2_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T2_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*s).typ, IL64(36134350135273744));
	T1_ = ((IL64(422212607672320) &((NU64)1<<((NU)((*T2_).kind)&63U)))!=0);
	if (T1_) goto LA3_;
	T1_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11));
	LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, markAsClosure__pewMCU9aolg9bl79a4WiPZ4HA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	s = (*n)._kind_4.sym;
	{
		NIM_BOOL T3_;
		tyArray__24KAM9afIUgUaqBaEBB6r9bg T6_;
		NimStringDesc* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = illegalCapture__BNaKs79aGny5MAVCr9a8Kurw_3lambdalifting(s);
		if (!T3_) goto LA4_;
		nimZeroMem((void*)T6_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
		T6_[0] = copyString((*(*s).name).s);
		T6_[1] = typeToString__QlvraUan7WbHowhAbvDvdA((*s).typ, ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
		T6_[2] = dollar___aQsiZUvE4SFfnWyKx1JgKA((*g).config, (*s).info);
		T7_ = (NimStringDesc*)0;
		T7_ = nsuFormatOpenArray(((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_9), T6_, 3);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T7_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__PI7oJkFuxeeTWjPTjlNxqg_10, NIM_FALSE);
	}
	goto LA1_;
	LA4_: ;
	{
		NIM_BOOL T9_;
		NIM_BOOL T11_;
		tyArray__24KAM9afIUgUaqBaEBB6r9bg T15_;
		NimStringDesc* T16_;
		T9_ = (NIM_BOOL)0;
		T9_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		if (T9_) goto LA10_;
		T11_ = (NIM_BOOL)0;
		T11_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 0));
		if (!(T11_)) goto LA12_;
		T11_ = !((((*(*owner).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 42))&63U)))!=0));
		LA12_: ;
		T9_ = T11_;
		LA10_: ;
		if (!!(T9_)) goto LA13_;
		nimZeroMem((void*)T15_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
		T15_[0] = copyString((*(*s).name).s);
		T15_[1] = copyString((*(*owner).name).s);
		T15_[2] = reprEnum((NI)(*(*owner).typ).callConv, (&NTI__yjAJ8w0h1PBaSwSGJ3P7IA_));
		T16_ = (NimStringDesc*)0;
		T16_ = nsuFormatOpenArray(((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_11), T15_, 3);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T16_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__PI7oJkFuxeeTWjPTjlNxqg_12, NIM_FALSE);
	}
	goto LA1_;
	LA13_: ;
	LA1_: ;
	(*(*owner).typ).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 12)) & 63);
	(*(*owner).typ).callConv = ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getEnvTypeForOwnerUp__JBqxLzBtZb2sydgcQO6g2w_2)(tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* r;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	r = getEnvTypeForOwner__JBqxLzBtZb2sydgcQO6g2w(c, owner, info);
	result = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21), owner);
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(r, IL64(35184378380288));
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, T1_, NIM_TRUE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, createUpField__vlqsfLq9b9cUFFP9cvYdZU3LA)(tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* c, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* dest, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* dep, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* refObj;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* fieldType;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* upIdent;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* upField;
	refObj = getEnvTypeForOwner__JBqxLzBtZb2sydgcQO6g2w(c, dest, info);
	obj = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(refObj, IL64(35184378380288));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isDefined__jkXTnxDf8MX1Pmks3s0XxA((*(*c).graph).config, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_13));
		if (!T3_) goto LA4_;
		fieldType = getEnvTypeForOwnerUp__JBqxLzBtZb2sydgcQO6g2w_2(c, dep, info);
	}
	goto LA1_;
	LA4_: ;
	{
		fieldType = getEnvTypeForOwner__JBqxLzBtZb2sydgcQO6g2w(c, dep, info);
	}
	LA1_: ;
	{
		if (!(refObj == fieldType)) goto LA9_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*dep).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_14), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__PI7oJkFuxeeTWjPTjlNxqg_15, NIM_FALSE);
	}
	LA9_: ;
	upIdent = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*(*c).graph).cache, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_16));
	upField = lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg((*obj).n, upIdent);
	{
		if (!!((upField == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA13_;
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T17_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T18_;
			T17_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T17_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*upField).typ, IL64(35184378380288));
			T18_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T18_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(fieldType, IL64(35184378380288));
			if (!!((T17_ == T18_))) goto LA19_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*c).graph).config, (*dep).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_17), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__PI7oJkFuxeeTWjPTjlNxqg_18, NIM_FALSE);
		}
		LA19_: ;
	}
	goto LA11_;
	LA13_: ;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
		result = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19), upIdent, (*obj).owner, (*(*obj).owner).info, 0);
		asgnRef((void**) (&(*result).typ), fieldType);
		rawAddField__5lAtboIt7Cs3LrzdvDm30A(obj, result);
	}
	LA11_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, detectCapturedVars__knMMYMrxMvpPAdvZhU1Tjg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* c) {
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		NIM_BOOL innerProc;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* ow;
		s = (*n)._kind_4.sym;
		{
			NIM_BOOL T4_;
			NIM_BOOL T5_;
			T4_ = (NIM_BOOL)0;
			T5_ = (NIM_BOOL)0;
			T5_ = ((126976 &((NU32)1<<((NU)((*s).kind)&31U)))!=0);
			if (!(T5_)) goto LA6_;
			T5_ = !(((*s).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			LA6_: ;
			T4_ = T5_;
			if (!(T4_)) goto LA7_;
			T4_ = ((*(*s).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
			LA7_: ;
			if (!T4_) goto LA8_;
			addClosureParam__lKI5vTqvn65UP6LyU15ZDg(c, s, (*n).info);
			(*c).somethingToDo = NIM_TRUE;
		}
		LA8_: ;
		innerProc = isInnerProc__tZttBPVF68vMBBdix9bG4sQ(s);
		{
			if (!innerProc) goto LA12_;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
				if (!(T16_)) goto LA17_;
				T16_ = ((*(*s).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
				LA17_: ;
				if (!T16_) goto LA18_;
				(*c).somethingToDo = NIM_TRUE;
			}
			LA18_: ;
			{
				NIM_BOOL T22_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body;
				T22_ = (NIM_BOOL)0;
				T22_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*c).processed), (*s).Sup.id);
				if (!!(T22_)) goto LA23_;
				body = transformBody__ocxOgPRHWfivNZELIhOv7w((*c).graph, s, NIM_TRUE);
				detectCapturedVars__knMMYMrxMvpPAdvZhU1Tjg(body, s, c);
			}
			LA23_: ;
		}
		LA12_: ;
		ow = skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3(s);
		{
			if (!(ow == owner)) goto LA27_;
			{
				NIM_BOOL T31_;
				T31_ = (NIM_BOOL)0;
				T31_ = ((*owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
				if (!(T31_)) goto LA32_;
				T31_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
				LA32_: ;
				if (!T31_) goto LA33_;
				(*c).somethingToDo = NIM_TRUE;
				addClosureParam__lKI5vTqvn65UP6LyU15ZDg(c, owner, (*n).info);
				{
					NIM_BOOL T37_;
					T37_ = (NIM_BOOL)0;
					T37_ = interestingIterVar__BNaKs79aGny5MAVCr9a8Kurw_2lambdalifting(s);
					if (!T37_) goto LA38_;
					{
						NIM_BOOL T42_;
						tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T45_;
						T42_ = (NIM_BOOL)0;
						T42_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*c).capturedVars), (*s).Sup.id);
						if (!!(T42_)) goto LA43_;
						T45_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
						T45_ = getHiddenParam__EE7nw3Cq0S1IZY9aGfs1AtA((*c).graph, owner);
						obj = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*T45_).typ, IL64(35184378380288));
						{
							tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T48_;
							T48_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
							T48_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*(*c).graph).cache, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_3));
							if (!((*(*s).name).Sup.id == (*T48_).Sup.id)) goto LA49_;
							(*(*(*(*obj).n)._kind_6.sons->data[((NI) 0)])._kind_4.sym).Sup.id = ((NI64)-((*s).Sup.id));
						}
						goto LA46_;
						LA49_: ;
						{
							addField__hrnJBvN8tSy4gj6R5QDcYw(obj, s, (*(*c).graph).cache);
						}
						LA46_: ;
					}
					LA43_: ;
				}
				LA38_: ;
			}
			LA33_: ;
		}
		goto LA25_;
		LA27_: ;
		{
			NIM_BOOL T53_;
			NIM_BOOL T54_;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* w;
			T53_ = (NIM_BOOL)0;
			T54_ = (NIM_BOOL)0;
			T54_ = innerProc;
			if (!(T54_)) goto LA55_;
			T54_ = ((*(*s).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
			LA55_: ;
			T53_ = T54_;
			if (T53_) goto LA56_;
			T53_ = interestingVar__BNaKs79aGny5MAVCr9a8Kurwlambdalifting(s);
			LA56_: ;
			if (!T53_) goto LA57_;
			(*c).somethingToDo = NIM_TRUE;
			markAsClosure__pewMCU9aolg9bl79a4WiPZ4HA((*c).graph, owner, n);
			addClosureParam__lKI5vTqvn65UP6LyU15ZDg(c, owner, (*n).info);
			{
				NIM_BOOL T61_;
				NIM_BOOL T63_;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj_2;
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T66_;
				T61_ = (NIM_BOOL)0;
				T61_ = interestingVar__BNaKs79aGny5MAVCr9a8Kurwlambdalifting(s);
				if (!(T61_)) goto LA62_;
				T63_ = (NIM_BOOL)0;
				T63_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*c).capturedVars), (*s).Sup.id);
				T61_ = !(T63_);
				LA62_: ;
				if (!T61_) goto LA64_;
				T66_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
				T66_ = getEnvTypeForOwner__JBqxLzBtZb2sydgcQO6g2w(c, ow, (*n).info);
				obj_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T66_, IL64(35184378380288));
				addField__hrnJBvN8tSy4gj6R5QDcYw(obj_2, s, (*(*c).graph).cache);
			}
			LA64_: ;
			w = skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3(owner);
			{
				NIM_BOOL T69_;
				NIM_BOOL T71_;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* last;
				T69_ = (NIM_BOOL)0;
				T69_ = isInnerProc__tZttBPVF68vMBBdix9bG4sQ(w);
				if (T69_) goto LA70_;
				T71_ = (NIM_BOOL)0;
				T71_ = ((*owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
				if (!(T71_)) goto LA72_;
				T71_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
				LA72_: ;
				T69_ = T71_;
				LA70_: ;
				if (!T69_) goto LA73_;
				{
					NIM_BOOL T77_;
					T77_ = (NIM_BOOL)0;
					T77_ = ((*owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
					if (!(T77_)) goto LA78_;
					T77_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
					LA78_: ;
					if (!T77_) goto LA79_;
					w = owner;
				}
				LA79_: ;
				{
					NIM_BOOL T83_;
					T83_ = (NIM_BOOL)0;
					T83_ = ((*ow).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
					if (!(T83_)) goto LA84_;
					T83_ = ((*(*ow).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
					LA84_: ;
					if (!T83_) goto LA85_;
					last = skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3(ow);
				}
				goto LA81_;
				LA85_: ;
				{
					last = ow;
				}
				LA81_: ;
				{
					while (1) {
						NIM_BOOL T90_;
						NIM_BOOL T91_;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* up;
						T90_ = (NIM_BOOL)0;
						T91_ = (NIM_BOOL)0;
						T91_ = !((w == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
						if (!(T91_)) goto LA92_;
						T91_ = !(((*w).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)));
						LA92_: ;
						T90_ = T91_;
						if (!(T90_)) goto LA93_;
						T90_ = !((last == w));
						LA93_: ;
						if (!T90_) goto LA89;
						up = skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3(w);
						markAsClosure__pewMCU9aolg9bl79a4WiPZ4HA((*c).graph, w, n);
						addClosureParam__lKI5vTqvn65UP6LyU15ZDg(c, w, (*n).info);
						createUpField__vlqsfLq9b9cUFFP9cvYdZU3LA(c, w, up, (*n).info);
						w = up;
					} LA89: ;
				}
			}
			LA73_: ;
		}
		goto LA25_;
		LA57_: ;
		LA25_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 125):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 132):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	{
		{
			if (!!(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)))) goto LA98_;
			detectCapturedVars__knMMYMrxMvpPAdvZhU1Tjg((*n)._kind_6.sons->data[((NI) 0)], owner, c);
		}
		LA98_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109):
	{
		detectCapturedVars__knMMYMrxMvpPAdvZhU1Tjg((*n)._kind_6.sons->data[((NI) 0)], owner, c);
	}
	break;
	default:
	{
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA104;
					i = i_2;
					detectCapturedVars__knMMYMrxMvpPAdvZhU1Tjg((*n)._kind_6.sons->data[i], owner, c);
					i_2 += ((NI) 1);
				} LA104: ;
			}
		}
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, initLiftingPass__mkHIcVQZdXl9cGPFvTV4ZWA)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw* Result) {
	NI T1_;
	(*Result).processed.elems = 0;
	(*Result).processed.counter = 0;
	(*Result).processed.max = 0;
	unsureAsgnRef((void**)&(*Result).processed.head, NIM_NIL);
	unsureAsgnRef((void**)&(*Result).processed.data, NIM_NIL);
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < 34; T1_++) {
	(*Result).processed.a[T1_] = 0;
	}
	unsureAsgnRef((void**)&(*Result).envVars.data, NIM_NIL);
	(*Result).envVars.counter = 0;
	(*Result).inContainer = 0;
	unsureAsgnRef((void**)&(*Result).unownedEnvVars.data, NIM_NIL);
	(*Result).unownedEnvVars.counter = 0;
	initIntSet__n8oDZMn19bEdodSnrBQB9a1Q((&(*Result).processed));
	incl__jENnK9c9bPE73pKmo2vYjpqg((&(*Result).processed), (*fn).Sup.id);
	initTable__TJKMxrEPQUpx86MsTl1C3A(((NI) 32), (&(*Result).envVars));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newEnvVar__eDqCayFpoOQA1G9cygMQKxA)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T1_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ(cache, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_21));
	v = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8), T1_, owner, info, 0);
	(*v).flags = IL64(274911461376);
	asgnRef((void**) (&(*v).typ), typ);
	result = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(v);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, asOwnedRef__Myowsqh71MOvPLm9bgYQ50A)(tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* result;
	result = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	{
		if (!(((*(*(*c).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 42))&63U)))!=0)) goto LA3_;
		result = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 45), (*t).owner);
		(*result).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 4)) & 63);
		rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(result, t, NIM_TRUE);
	}
	goto LA1_;
	LA3_: ;
	{
		result = t;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, setupEnvVar__uYj8l4iSUGRUAThDXmR3AQ_2)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* d, tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T7_ = getHiddenParam__EE7nw3Cq0S1IZY9aGfs1AtA((*d).graph, owner);
		result = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T7_);
		goto BeforeRet_;
	}
	LA5_: ;
	result = getOrDefault__OX9anFuDn9bfK9aeoL9blUUBvw((*c).envVars, (*owner).Sup.id);
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* envVarType;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T16_;
		if (!(result == 0)) goto LA10_;
		envVarType = getOrDefault__9bQKf8dFvOTPFC2tZLVBE7A((*d).ownerToType, (*owner).Sup.id);
		{
			if (!(envVarType == 0)) goto LA14_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*d).graph).config, (*owner).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_19), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__PI7oJkFuxeeTWjPTjlNxqg_20, NIM_FALSE);
		}
		LA14_: ;
		T16_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T16_ = asOwnedRef__Myowsqh71MOvPLm9bgYQ50A(d, envVarType);
		result = newEnvVar__eDqCayFpoOQA1G9cygMQKxA((*(*d).graph).cache, owner, T16_, info);
		X5BX5Deq___tMEyAvlcC3r82WGaTaSYrQ((&(*c).envVars), (*owner).Sup.id, result);
		{
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v;
			tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T21_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T22_;
			if (!(((*(*(*d).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 42))&63U)))!=0)) goto LA19_;
			T21_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
			T21_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*(*d).graph).cache, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_22));
			v = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8), T21_, owner, info, 0);
			(*v).flags = IL64(274911461376);
			asgnRef((void**) (&(*v).typ), envVarType);
			T22_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T22_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(v);
			X5BX5Deq___tMEyAvlcC3r82WGaTaSYrQ((&(*c).unownedEnvVars), (*owner).Sup.id, T22_);
		}
		LA19_: ;
	}
	LA10_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newCall__8664d9ayvIMAWB9cM5EcHP7Q)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* a, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* b) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*a).info);
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(a);
	add__P8dDSotTW25BkfbyspojGg(result, T1_);
	add__P8dDSotTW25BkfbyspojGg(result, b);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newAsgnStmt__0EDAdA9aH20kXbo0qceLIoQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73), info, ((NI) 2));
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 0)]), le);
	asgnRef((void**) (&(*result)._kind_6.sons->data[((NI) 1)]), ri);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, createTypeBoundOpsLL__zNEHc9bDojTsulmL716BbGw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* refType, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T1_;
	T1_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T1_ = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(refType);
	createTypeBoundOps__HRpOwQj0TjFM8eZsKc7jlw(g, ((tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug*) NIM_NIL), T1_, info);
	createTypeBoundOps__HRpOwQj0TjFM8eZsKc7jlw(g, ((tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug*) NIM_NIL), refType, info);
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = (((*refType).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 31))&63U)))!=0);
		if (T4_) goto LA5_;
		T4_ = (((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0);
		LA5_: ;
		if (!T4_) goto LA6_;
		(*owner).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 41)) & 63);
	}
	LA6_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, getUpViaParam__5aTkGMxbYzGq8tgBuEAcvw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* p;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	p = getHiddenParam__EE7nw3Cq0S1IZY9aGfs1AtA(g, owner);
	result = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(p);
	{
		NIM_BOOL T3_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* upField;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T7_;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T7_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*p).typ, IL64(35184378380288));
		T8_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T8_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*g).cache, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_16));
		upField = lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg((*T7_).n, T8_);
		{
			if (!(upField == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA11_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*owner).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_24), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__PI7oJkFuxeeTWjPTjlNxqg_25, NIM_FALSE);
		}
		goto LA9_;
		LA11_: ;
		{
			result = rawIndirectAccess__8aXgrGQvaIrhwp6o9cuBYoA(result, upField, (*p).info);
		}
		LA9_: ;
	}
	LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, rawClosureCreation__uYj8l4iSUGRUAThDXmR3AQ)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* d, tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* env;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* upField;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T42_;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T43_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*owner).info);
	env = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T7_ = getHiddenParam__EE7nw3Cq0S1IZY9aGfs1AtA((*d).graph, owner);
		env = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T7_);
	}
	goto LA1_;
	LA5_: ;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T18_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T19_;
		env = setupEnvVar__uYj8l4iSUGRUAThDXmR3AQ_2(owner, d, c, info);
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v;
			if (!((*env).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA11_;
			v = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99), (*env).info);
			addVar__qOCBdprWtK4hxer73SEdQA(v, env);
			add__P8dDSotTW25BkfbyspojGg(result, v);
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* unowned;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** T17_;
				if (!(((*(*(*d).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 42))&63U)))!=0)) goto LA15_;
				T17_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
				T17_ = X5BX5D___X7HRLXyMghOAScJitThqsw((&(*c).unownedEnvVars), (*owner).Sup.id);
				unowned = (*T17_);
				addVar__qOCBdprWtK4hxer73SEdQA(v, unowned);
			}
			LA15_: ;
		}
		LA11_: ;
		T18_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T18_ = getSysSym__9bvw79ck1FDiWpnBYh88rEfw((*d).graph, (*env).info, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_23));
		T19_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T19_ = newCall__8664d9ayvIMAWB9cM5EcHP7Q(T18_, env);
		add__P8dDSotTW25BkfbyspojGg(result, T19_);
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* unowned_2;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** T24_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* env2;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T25_;
			if (!(((*(*(*d).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 42))&63U)))!=0)) goto LA22_;
			T24_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
			T24_ = X5BX5D___X7HRLXyMghOAScJitThqsw((&(*c).unownedEnvVars), (*owner).Sup.id);
			unowned_2 = (*T24_);
			env2 = copyTree__Dsjo9bte8vGxzhtcSrsTyiQ(env);
			asgnRef((void**) (&(*env2).typ), (*unowned_2).typ);
			T25_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T25_ = newAsgnStmt__0EDAdA9aH20kXbo0qceLIoQ(unowned_2, env2, (*env).info);
			add__P8dDSotTW25BkfbyspojGg(result, T25_);
			createTypeBoundOpsLL__zNEHc9bDojTsulmL716BbGw((*d).graph, (*unowned_2).typ, (*env).info, owner);
		}
		LA22_: ;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast((*(*owner).typ).n);
			i_2 = ((NI) 1);
			{
				while (1) {
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* local;
					if (!(i_2 < colontmp_)) goto LA28;
					i = i_2;
					local = (*(*(*(*owner).typ).n)._kind_6.sons->data[i])._kind_4.sym;
					{
						NIM_BOOL T31_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fieldAccess;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T34_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T35_;
						T31_ = (NIM_BOOL)0;
						T31_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*d).capturedVars), (*local).Sup.id);
						if (!T31_) goto LA32_;
						fieldAccess = indirectAccess__fh4Yh9bIIARGtqRFUnv8SDA(env, local, (*env).info);
						T34_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T34_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(local);
						T35_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T35_ = newAsgnStmt__0EDAdA9aH20kXbo0qceLIoQ(fieldAccess, T34_, (*env).info);
						add__P8dDSotTW25BkfbyspojGg(result, T35_);
						createTypeBoundOps__HRpOwQj0TjFM8eZsKc7jlw((*d).graph, ((tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug*) NIM_NIL), (*fieldAccess).typ, (*env).info);
						{
							NIM_BOOL T38_;
							T38_ = (NIM_BOOL)0;
							T38_ = (((*(*fieldAccess).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 31))&63U)))!=0);
							if (T38_) goto LA39_;
							T38_ = (((*(*(*d).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0);
							LA39_: ;
							if (!T38_) goto LA40_;
							(*owner).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 41)) & 63);
						}
						LA40_: ;
					}
					LA32_: ;
					i_2 += ((NI) 1);
				} LA28: ;
			}
		}
	}
	LA1_: ;
	T42_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T42_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*env).typ, IL64(35184378380288));
	T43_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T43_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*(*d).graph).cache, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_16));
	upField = lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg((*T42_).n, T43_);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* up;
		if (!!((upField == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA46_;
		up = getUpViaParam__5aTkGMxbYzGq8tgBuEAcvw((*d).graph, owner);
		{
			NIM_BOOL T50_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T52_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T53_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T56_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T57_;
			T50_ = (NIM_BOOL)0;
			T50_ = !((up == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
			if (!(T50_)) goto LA51_;
			T52_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T52_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*upField).typ, IL64(35184378380288));
			T53_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T53_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*up).typ, IL64(35184378380288));
			T50_ = (T52_ == T53_);
			LA51_: ;
			if (!T50_) goto LA54_;
			T56_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T56_ = rawIndirectAccess__8aXgrGQvaIrhwp6o9cuBYoA(env, upField, (*env).info);
			T57_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T57_ = newAsgnStmt__0EDAdA9aH20kXbo0qceLIoQ(T56_, up, (*env).info);
			add__P8dDSotTW25BkfbyspojGg(result, T57_);
		}
		goto LA48_;
		LA54_: ;
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*d).graph).config, (*env).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_26), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__PI7oJkFuxeeTWjPTjlNxqg_27, NIM_FALSE);
		}
		LA48_: ;
	}
	LA46_: ;
	createTypeBoundOpsLL__zNEHc9bDojTsulmL716BbGw((*d).graph, (*env).typ, (*owner).info, owner);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, finishClosureCreation__yhHyVa9bbyRc86LofEPTIBw)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* d, tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw* c, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* res) {
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* unowned;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* nilLit;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T5_;
		if (!(((*(*(*d).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 42))&63U)))!=0)) goto LA3_;
		unowned = X5BX5D___OX9anFuDn9bfK9aeoL9blUUBvw_2((*c).unownedEnvVars, (*owner).Sup.id);
		nilLit = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23), info, (*unowned).typ);
		T5_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T5_ = newAsgnStmt__0EDAdA9aH20kXbo0qceLIoQ(unowned, nilLit, info);
		add__P8dDSotTW25BkfbyspojGg(res, T5_);
		createTypeBoundOpsLL__zNEHc9bDojTsulmL716BbGw((*d).graph, (*unowned).typ, info, owner);
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, makeClosure__fa9aZDXQ04CAodm0trAX6LA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* prc, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* env, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 155), info, (*prc).typ);
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(prc);
	add__P8dDSotTW25BkfbyspojGg(result, T1_);
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T7_;
		if (!(env == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA4_;
		T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T6_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg(g, info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 5));
		T7_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T7_ = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23), info, T6_);
		add__P8dDSotTW25BkfbyspojGg(result, T7_);
	}
	goto LA2_;
	LA4_: ;
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T11_;
			T11_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T11_ = skipConv__BH9abOhPX8pH0DnEWlRxmlw(env);
			if (!((*T11_).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 155))) goto LA12_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_28), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__PI7oJkFuxeeTWjPTjlNxqg_29, NIM_FALSE);
		}
		LA12_: ;
		add__P8dDSotTW25BkfbyspojGg(result, env);
	}
	LA2_: ;
	createTypeBoundOps__HRpOwQj0TjFM8eZsKc7jlw(g, ((tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug*) NIM_NIL), (*result).typ, info);
	{
		NIM_BOOL T16_;
		T16_ = (NIM_BOOL)0;
		T16_ = (((*(*result).typ).flags &((NU64)1<<((NU)(((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 31))&63U)))!=0);
		if (T16_) goto LA17_;
		T16_ = (((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 40))&63U)))!=0);
		LA17_: ;
		if (!T16_) goto LA18_;
		(*prc).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 41)) & 63);
	}
	LA18_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, closureCreationForIter__aBUE4CjNZyw9ch83XM4bSVA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* iter, tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* d, tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw* c) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* v;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T1_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T2_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* vnode;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T13_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T14_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* upField;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T15_;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T16_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T30_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126), (*iter).info, (*(*iter)._kind_4.sym).typ);
	owner = skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3((*iter)._kind_4.sym);
	T1_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T1_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*(*d).graph).cache, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_21));
	v = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8), T1_, owner, (*iter).info, 0);
	(*v).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 25)) & 63);
	T2_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T2_ = getHiddenParam__EE7nw3Cq0S1IZY9aGfs1AtA((*d).graph, (*iter)._kind_4.sym);
	asgnRef((void**) (&(*v).typ), asOwnedRef__Myowsqh71MOvPLm9bgYQ50A(d, (*T2_).typ));
	vnode = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T5_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* it;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T9_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T10_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T11_;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
		if (!(T5_)) goto LA6_;
		T5_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		LA6_: ;
		if (!T5_) goto LA7_;
		it = getHiddenParam__EE7nw3Cq0S1IZY9aGfs1AtA((*d).graph, owner);
		T9_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T9_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*it).typ, IL64(35184378380288));
		T10_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T10_ = addUniqueField__CLL3aqLIY5XbgRQPQDI3cw(T9_, v, (*(*d).graph).cache);
		T11_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T11_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(it);
		vnode = indirectAccess__fh4Yh9bIIARGtqRFUnv8SDA(T11_, v, (*v).info);
	}
	goto LA3_;
	LA7_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* vs;
		vnode = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(v);
		vs = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99), (*iter).info);
		addVar__qOCBdprWtK4hxer73SEdQA(vs, vnode);
		add__P8dDSotTW25BkfbyspojGg(result, vs);
	}
	LA3_: ;
	T13_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T13_ = getSysSym__9bvw79ck1FDiWpnBYh88rEfw((*d).graph, (*iter).info, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_23));
	T14_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T14_ = newCall__8664d9ayvIMAWB9cM5EcHP7Q(T13_, vnode);
	add__P8dDSotTW25BkfbyspojGg(result, T14_);
	createTypeBoundOpsLL__zNEHc9bDojTsulmL716BbGw((*d).graph, (*vnode).typ, (*iter).info, owner);
	T15_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T15_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*v).typ, IL64(35184378380288));
	T16_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T16_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*(*d).graph).cache, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_16));
	upField = lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg((*T15_).n, T16_);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* u;
		if (!!((upField == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA19_;
		u = setupEnvVar__uYj8l4iSUGRUAThDXmR3AQ_2(owner, d, c, (*iter).info);
		{
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T23_;
			tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T24_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T27_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T28_;
			T23_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T23_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*u).typ, IL64(35184378380288));
			T24_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
			T24_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*upField).typ, IL64(35184378380288));
			if (!(T23_ == T24_)) goto LA25_;
			T27_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T27_ = rawIndirectAccess__8aXgrGQvaIrhwp6o9cuBYoA(vnode, upField, (*iter).info);
			T28_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T28_ = newAsgnStmt__0EDAdA9aH20kXbo0qceLIoQ(T27_, u, (*iter).info);
			add__P8dDSotTW25BkfbyspojGg(result, T28_);
		}
		goto LA21_;
		LA25_: ;
		{
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*d).graph).config, (*iter).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_30), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__PI7oJkFuxeeTWjPTjlNxqg_31, NIM_FALSE);
		}
		LA21_: ;
	}
	LA19_: ;
	T30_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T30_ = makeClosure__fa9aZDXQ04CAodm0trAX6LA((*d).graph, (*iter)._kind_4.sym, vnode, (*iter).info);
	add__P8dDSotTW25BkfbyspojGg(result, T30_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, symToClosure__1JM0Ep6665B6crlfoxbCuQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* d, tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw* c) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	s = (*n)._kind_4.sym;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* available;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T5_;
		if (!(s == owner)) goto LA3_;
		available = getHiddenParam__EE7nw3Cq0S1IZY9aGfs1AtA((*d).graph, owner);
		T5_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T5_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(available);
		result = makeClosure__fa9aZDXQ04CAodm0trAX6LA((*d).graph, s, T5_, (*n).info);
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = ((*s).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
		if (!(T7_)) goto LA8_;
		T7_ = ((*(*s).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		LA8_: ;
		if (!T7_) goto LA9_;
		result = closureCreationForIter__aBUE4CjNZyw9ch83XM4bSVA(n, d, c);
	}
	goto LA1_;
	LA9_: ;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T12_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T15_;
		T12_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T12_ = skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3(s);
		if (!(T12_ == owner)) goto LA13_;
		T15_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T15_ = setupEnvVar__uYj8l4iSUGRUAThDXmR3AQ_2(owner, d, c, (*n).info);
		result = makeClosure__fa9aZDXQ04CAodm0trAX6LA((*d).graph, s, T15_, (*n).info);
	}
	goto LA1_;
	LA13_: ;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* available_2;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* wanted;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T17_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* access;
		available_2 = getHiddenParam__EE7nw3Cq0S1IZY9aGfs1AtA((*d).graph, owner);
		T17_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T17_ = getHiddenParam__EE7nw3Cq0S1IZY9aGfs1AtA((*d).graph, s);
		wanted = (*T17_).typ;
		access = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(available_2);
		{
			while (1) {
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* upField;
				tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T24_;
				{
					if (!((*access).typ == wanted)) goto LA22_;
					result = makeClosure__fa9aZDXQ04CAodm0trAX6LA((*d).graph, s, access, (*n).info);
					goto BeforeRet_;
				}
				LA22_: ;
				obj = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*access).typ, IL64(35184378380288));
				T24_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
				T24_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*(*d).graph).cache, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_16));
				upField = lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg((*obj).n, T24_);
				{
					if (!(upField == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA27_;
					liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*d).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_32), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__PI7oJkFuxeeTWjPTjlNxqg_33, NIM_FALSE);
					result = n;
					goto BeforeRet_;
				}
				LA27_: ;
				access = rawIndirectAccess__8aXgrGQvaIrhwp6o9cuBYoA(access, upField, (*n).info);
			}
		}
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, accessViaEnvParam__8CYqf1nXlpBtnWvyO6vrCw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* envParam;
	NimStringDesc* T16_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	s = (*n)._kind_4.sym;
	envParam = getHiddenParam__EE7nw3Cq0S1IZY9aGfs1AtA(g, owner);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* access;
		if (!!((envParam == 0))) goto LA3_;
		access = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(envParam);
		{
			while (1) {
				tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* upField;
				tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T11_;
				obj = (*(*access).typ).sons->data[((NI) 0)];
				field = getFieldFromObj__a9b9aDcfE1em9bBkDPbo9cqoSg(obj, s);
				{
					if (!!((field == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA9_;
					result = rawIndirectAccess__8aXgrGQvaIrhwp6o9cuBYoA(access, field, (*n).info);
					goto BeforeRet_;
				}
				LA9_: ;
				T11_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
				T11_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*g).cache, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_16));
				upField = lookupInRecord__gYQxUKQhlRY6yBu3Ll2TYg((*obj).n, T11_);
				{
					if (!(upField == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL))) goto LA14_;
					goto LA5;
				}
				LA14_: ;
				access = rawIndirectAccess__8aXgrGQvaIrhwp6o9cuBYoA(access, upField, (*n).info);
			}
		} LA5: ;
	}
	LA3_: ;
	T16_ = (NimStringDesc*)0;
	T16_ = rawNewString(((*(*s).name).s ? (*(*s).name).s->Sup.len : 0) + 36);
appendString(T16_, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_34));
appendString(T16_, (*(*s).name).s);
	liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T16_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__PI7oJkFuxeeTWjPTjlNxqg_35, NIM_FALSE);
	result = n;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, accessViaEnvVar__1JM0Ep6665B6crlfoxbCuQ_3)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* d, tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw* c) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* access;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	access = setupEnvVar__uYj8l4iSUGRUAThDXmR3AQ_2(owner, d, c, (*n).info);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw** T5_;
		if (!(((*(*(*d).graph).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 42))&63U)))!=0)) goto LA3_;
		T5_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw**)0;
		T5_ = X5BX5D___X7HRLXyMghOAScJitThqsw((&(*c).unownedEnvVars), (*owner).Sup.id);
		access = (*T5_);
	}
	LA3_: ;
	obj = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*access).typ, IL64(35184378380288));
	field = getFieldFromObj__a9b9aDcfE1em9bBkDPbo9cqoSg(obj, (*n)._kind_4.sym);
	{
		if (!!((field == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA8_;
		result = rawIndirectAccess__8aXgrGQvaIrhwp6o9cuBYoA(access, field, (*n).info);
	}
	goto LA6_;
	LA8_: ;
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*(*d).graph).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_36), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__PI7oJkFuxeeTWjPTjlNxqg_37, NIM_FALSE);
		result = n;
	}
	LA6_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, liftCapturedVars__1JM0Ep6665B6crlfoxbCuQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ* d, tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw* c) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = n;
	switch ((*n).kind) {
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3):
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s;
		s = (*n)._kind_4.sym;
		{
			NIM_BOOL T4_;
			T4_ = (NIM_BOOL)0;
			T4_ = isInnerProc__tZttBPVF68vMBBdix9bG4sQ(s);
			if (!T4_) goto LA5_;
			{
				NIM_BOOL T9_;
				NI oldInContainer;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body;
				T9_ = (NIM_BOOL)0;
				T9_ = containsOrIncl__VFt0uM7bgfJ5age9alOsU9cg((&(*c).processed), (*s).Sup.id);
				if (!!(T9_)) goto LA10_;
				oldInContainer = (*c).inContainer;
				(*c).inContainer = ((NI) 0);
				body = transformBody__ocxOgPRHWfivNZELIhOv7w((*d).graph, s, NIM_FALSE);
				body = liftCapturedVars__1JM0Ep6665B6crlfoxbCuQ(body, s, d, c);
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T14_;
					T14_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T14_ = getOrDefault__OX9anFuDn9bfK9aeoL9blUUBvw((*c).envVars, (*s).Sup.id);
					if (!(T14_ == 0)) goto LA15_;
					asgnRef((void**) (&(*s)._kind_2.transformedBody), body);
				}
				goto LA12_;
				LA15_: ;
				{
					tyArray__AB6yfoUgfWM2NtGe9bzkCmw T18_;
					nimZeroMem((void*)T18_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
					T18_[0] = rawClosureCreation__uYj8l4iSUGRUAThDXmR3AQ(s, d, c, (*n).info);
					T18_[1] = body;
					asgnRef((void**) (&(*s)._kind_2.transformedBody), newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), T18_, 2));
					finishClosureCreation__yhHyVa9bbyRc86LofEPTIBw(s, d, (&(*c)), (*n).info, (*s)._kind_2.transformedBody);
				}
				LA12_: ;
				(*c).inContainer = oldInContainer;
			}
			LA10_: ;
			{
				if (!((*(*s).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9))) goto LA21_;
				result = symToClosure__1JM0Ep6665B6crlfoxbCuQ_2(n, owner, d, c);
			}
			LA21_: ;
		}
		goto LA2_;
		LA5_: ;
		{
			NIM_BOOL T24_;
			T24_ = (NIM_BOOL)0;
			T24_ = contains__R6uRTGpl30Ofaw4Ni3vawA((&(*d).capturedVars), (*s).Sup.id);
			if (!T24_) goto LA25_;
			{
				if (!!(((*s).owner == owner))) goto LA29_;
				result = accessViaEnvParam__8CYqf1nXlpBtnWvyO6vrCw((*d).graph, n, owner);
			}
			goto LA27_;
			LA29_: ;
			{
				NIM_BOOL T32_;
				NIM_BOOL T33_;
				T32_ = (NIM_BOOL)0;
				T33_ = (NIM_BOOL)0;
				T33_ = ((*owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
				if (!(T33_)) goto LA34_;
				T33_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
				LA34_: ;
				T32_ = T33_;
				if (!(T32_)) goto LA35_;
				T32_ = interestingIterVar__BNaKs79aGny5MAVCr9a8Kurw_2lambdalifting(s);
				LA35_: ;
				if (!T32_) goto LA36_;
				result = accessViaEnvParam__8CYqf1nXlpBtnWvyO6vrCw((*d).graph, n, owner);
			}
			goto LA27_;
			LA36_: ;
			{
				result = accessViaEnvVar__1JM0Ep6665B6crlfoxbCuQ_3(n, owner, d, c);
			}
			LA27_: ;
		}
		goto LA2_;
		LA25_: ;
		LA2_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 2):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 4) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 24):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 83):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 98):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 80):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 81):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 82):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 159):
	{
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 155):
	{
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* x;
			if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 23))) goto LA43_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), liftCapturedVars__1JM0Ep6665B6crlfoxbCuQ((*n)._kind_6.sons->data[((NI) 0)], owner, d, c));
			x = skipConv__BH9abOhPX8pH0DnEWlRxmlw((*n)._kind_6.sons->data[((NI) 0)]);
			{
				if (!((*x).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 155))) goto LA47_;
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), (*x)._kind_6.sons->data[((NI) 0)]);
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), (*x)._kind_6.sons->data[((NI) 1)]);
			}
			LA47_: ;
		}
		LA43_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 51) ... ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 52):
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 84):
	{
		{
			NIM_BOOL T52_;
			NI oldInContainer_2;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* m;
			T52_ = (NIM_BOOL)0;
			T52_ = !(((*n).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
			if (!(T52_)) goto LA53_;
			T52_ = ((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
			LA53_: ;
			if (!T52_) goto LA54_;
			oldInContainer_2 = (*c).inContainer;
			(*c).inContainer = ((NI) 0);
			m = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg((*(*n)._kind_6.sons->data[((NI) 0)])._kind_4.sym);
			asgnRef((void**) (&(*m).typ), (*n).typ);
			result = liftCapturedVars__1JM0Ep6665B6crlfoxbCuQ(m, owner, d, c);
			(*c).inContainer = oldInContainer_2;
		}
		LA54_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 58):
	{
		{
			NI T59_;
			T59_ = (NI)0;
			T59_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			if (!(T59_ == ((NI) 2))) goto LA60_;
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), liftCapturedVars__1JM0Ep6665B6crlfoxbCuQ((*n)._kind_6.sons->data[((NI) 1)], owner, d, c));
			{
				if (!((*(*n)._kind_6.sons->data[((NI) 1)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 155))) goto LA64_;
				result = (*n)._kind_6.sons->data[((NI) 1)];
			}
			LA64_: ;
		}
		LA60_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 109):
	{
		{
			if (!((*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 73) || (*(*n)._kind_6.sons->data[((NI) 0)]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 74))) goto LA69_;
			asgnRef((void**) (&(*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)]), liftCapturedVars__1JM0Ep6665B6crlfoxbCuQ((*(*n)._kind_6.sons->data[((NI) 0)])._kind_6.sons->data[((NI) 1)], owner, d, c));
		}
		goto LA67_;
		LA69_: ;
		{
			asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 0)]), liftCapturedVars__1JM0Ep6665B6crlfoxbCuQ((*n)._kind_6.sons->data[((NI) 0)], owner, d, c));
		}
		LA67_: ;
	}
	break;
	case ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 132):
	{
		result = n;
	}
	break;
	default:
	{
		NIM_BOOL inContainer;
		{
			NIM_BOOL T76_;
			T76_ = (NIM_BOOL)0;
			T76_ = ((*owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
			if (!(T76_)) goto LA77_;
			T76_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
			LA77_: ;
			if (!T76_) goto LA78_;
			{
				if (!(((*n).flags &((NU32)1<<((NU)(((tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg) 8))&31U)))!=0)) goto LA82_;
				asgnRef((void**) (&(*n)._kind_6.sons->data[((NI) 1)]), liftCapturedVars__1JM0Ep6665B6crlfoxbCuQ((*n)._kind_6.sons->data[((NI) 1)], owner, d, c));
				goto BeforeRet_;
			}
			LA82_: ;
		}
		LA78_: ;
		inContainer = ((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 38) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 41));
		{
			if (!inContainer) goto LA86_;
			(*c).inContainer += ((NI) 1);
		}
		LA86_: ;
		{
			NI i;
			NI colontmp_;
			NI i_2;
			i = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
			i_2 = ((NI) 0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA90;
					i = i_2;
					asgnRef((void**) (&(*n)._kind_6.sons->data[i]), liftCapturedVars__1JM0Ep6665B6crlfoxbCuQ((*n)._kind_6.sons->data[i], owner, d, c));
					i_2 += ((NI) 1);
				} LA90: ;
			}
		}
		{
			if (!inContainer) goto LA93_;
			(*c).inContainer -= ((NI) 1);
		}
		LA93_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, liftLambdas__dmTb5DSkbT8504NMz3NOoA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body, NIM_BOOL* tooEarly) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	NIM_BOOL isCompileTime;
	NIM_BOOL T1_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (((*fn).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 27))&63U)))!=0);
	if (T1_) goto LA2_;
	T1_ = ((*fn).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17));
	LA2_: ;
	isCompileTime = T1_;
	{
		NIM_BOOL T5_;
		NIM_BOOL T6_;
		NIM_BOOL T8_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T11_;
		T5_ = (NIM_BOOL)0;
		T6_ = (NIM_BOOL)0;
		T6_ = ((*body).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1));
		if (T6_) goto LA7_;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*(*g).config).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 3));
		if (!(T8_)) goto LA9_;
		T8_ = !(isCompileTime);
		LA9_: ;
		T6_ = T8_;
		LA7_: ;
		T5_ = T6_;
		if (T5_) goto LA10_;
		T11_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T11_ = skipGenericOwner__lIu8wX6Beq6dBJgESOFFjg_3(fn);
		T5_ = !(((*T11_).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 6)));
		LA10_: ;
		if (!T5_) goto LA12_;
		result = body;
		(*tooEarly) = NIM_TRUE;
	}
	goto LA3_;
	LA12_: ;
	{
		tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ d;
		nimZeroMem((void*)(&d), sizeof(tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ));
		initDetectionPass__P5KW8HQhQCFeBR8BnZtcJw(g, fn, (&d));
		detectCapturedVars__knMMYMrxMvpPAdvZhU1Tjg(body, fn, (&d));
		{
			NIM_BOOL T17_;
			NIM_BOOL T19_;
			T17_ = (NIM_BOOL)0;
			T17_ = !(d.somethingToDo);
			if (!(T17_)) goto LA18_;
			T19_ = (NIM_BOOL)0;
			T19_ = ((*fn).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
			if (!(T19_)) goto LA20_;
			T19_ = ((*(*fn).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
			LA20_: ;
			T17_ = T19_;
			LA18_: ;
			if (!T17_) goto LA21_;
			addClosureParam__lKI5vTqvn65UP6LyU15ZDg((&d), fn, (*body).info);
			d.somethingToDo = NIM_TRUE;
		}
		LA21_: ;
		{
			tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw c;
			if (!d.somethingToDo) goto LA25_;
			nimZeroMem((void*)(&c), sizeof(tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw));
			initLiftingPass__mkHIcVQZdXl9cGPFvTV4ZWA(fn, (&c));
			result = liftCapturedVars__1JM0Ep6665B6crlfoxbCuQ(body, fn, (&d), (&c));
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T29_;
				tyArray__AB6yfoUgfWM2NtGe9bzkCmw T32_;
				T29_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T29_ = getOrDefault__OX9anFuDn9bfK9aeoL9blUUBvw(c.envVars, (*fn).Sup.id);
				if (!!((T29_ == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA30_;
				nimZeroMem((void*)T32_, sizeof(tyArray__AB6yfoUgfWM2NtGe9bzkCmw));
				T32_[0] = rawClosureCreation__uYj8l4iSUGRUAThDXmR3AQ(fn, (&d), (&c), (*body).info);
				T32_[1] = result;
				result = newTree__FpOm4fidh9bWdkMa1BMRJkQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), T32_, 2);
				finishClosureCreation__yhHyVa9bbyRc86LofEPTIBw(fn, (&d), (&c), (*body).info, result);
			}
			LA30_: ;
		}
		goto LA23_;
		LA25_: ;
		{
			result = body;
		}
		LA23_: ;
	}
	LA3_: ;
	return result;
}
static N_INLINE(NIM_BOOL, liftingHarmful__VHxic9aDgFru4d09c6I7A1HQlambdalifting)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	NIM_BOOL result;
	NIM_BOOL isCompileTime;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (((*owner).flags &((NU64)1<<((NU)(((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 27))&63U)))!=0);
	if (T1_) goto LA2_;
	T1_ = ((*owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 17));
	LA2_: ;
	isCompileTime = T1_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*conf).backend == ((tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g) 3));
	if (!(T3_)) goto LA4_;
	T3_ = !(isCompileTime);
	LA4_: ;
	result = T3_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, liftIterSym__8CYqf1nXlpBtnWvyO6vrCw_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* iter;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* hp;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* env;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T16_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T17_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T18_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = liftingHarmful__VHxic9aDgFru4d09c6I7A1HQlambdalifting((*g).config, owner);
		if (!T3_) goto LA4_;
		result = n;
		goto BeforeRet_;
	}
	LA4_: ;
	iter = (*n)._kind_4.sym;
	result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126), (*n).info, (*n).typ);
	hp = getHiddenParam__EE7nw3Cq0S1IZY9aGfs1AtA(g, iter);
	env = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T8_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* it;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T12_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T13_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T14_;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*owner).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
		if (!(T8_)) goto LA9_;
		T8_ = ((*(*owner).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		LA9_: ;
		if (!T8_) goto LA10_;
		it = getHiddenParam__EE7nw3Cq0S1IZY9aGfs1AtA(g, owner);
		T12_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T12_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*it).typ, IL64(35184372088832));
		T13_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T13_ = addUniqueField__CLL3aqLIY5XbgRQPQDI3cw((*T12_).sons->data[((NI) 0)], hp, (*g).cache);
		T14_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T14_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(it);
		env = indirectAccess__fh4Yh9bIIARGtqRFUnv8SDA(T14_, hp, (*hp).info);
	}
	goto LA6_;
	LA10_: ;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* e;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v;
		e = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9), (*iter).name, owner, (*n).info, 0);
		asgnRef((void**) (&(*e).typ), (*hp).typ);
		(*e).flags = (*hp).flags;
		env = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(e);
		v = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99), (*n).info);
		addVar__qOCBdprWtK4hxer73SEdQA(v, env);
		add__P8dDSotTW25BkfbyspojGg(result, v);
	}
	LA6_: ;
	T16_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T16_ = getSysSym__9bvw79ck1FDiWpnBYh88rEfw(g, (*n).info, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_23));
	T17_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T17_ = newCall__8664d9ayvIMAWB9cM5EcHP7Q(T16_, env);
	add__P8dDSotTW25BkfbyspojGg(result, T17_);
	createTypeBoundOpsLL__zNEHc9bDojTsulmL716BbGw(g, (*env).typ, (*n).info, owner);
	T18_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T18_ = makeClosure__fa9aZDXQ04CAodm0trAX6LA(g, iter, env, (*n).info);
	add__P8dDSotTW25BkfbyspojGg(result, T18_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, liftForLoop__d1skGaYPbh4srEm2IRKTwg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call;
	NI T13_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* env;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* op;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* loopBody;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* whileLoop;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T37_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v2;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* vpart;
	tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw T38_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T53_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* bs;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ibs;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* elifBranch;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* br;
	NI T59_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = liftingHarmful__VHxic9aDgFru4d09c6I7A1HQlambdalifting((*g).config, owner);
		if (!T3_) goto LA4_;
		result = body;
		goto BeforeRet_;
	}
	LA4_: ;
	{
		NIM_BOOL T8_;
		NI T10_;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*body).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 94));
		if (!(T8_)) goto LA9_;
		T10_ = (NI)0;
		T10_ = len__P89cqdlERShb9alU3iC0yj8wast(body);
		T8_ = ((*(*body)._kind_6.sons->data[(NI)(T10_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*(*body)._kind_6.sons->data[(NI)(T10_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*(*body)._kind_6.sons->data[(NI)(T10_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*(*body)._kind_6.sons->data[(NI)(T10_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*(*body)._kind_6.sons->data[(NI)(T10_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*(*body)._kind_6.sons->data[(NI)(T10_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*(*body)._kind_6.sons->data[(NI)(T10_ - ((NI) 2))]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32));
		LA9_: ;
		if (!!(T8_)) goto LA11_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*body).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_38), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__PI7oJkFuxeeTWjPTjlNxqg_39, NIM_FALSE);
		result = body;
		goto BeforeRet_;
	}
	LA11_: ;
	T13_ = (NI)0;
	T13_ = len__P89cqdlERShb9alU3iC0yj8wast(body);
	call = (*body)._kind_6.sons->data[(NI)(T13_ - ((NI) 2))];
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*body).info);
	env = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	op = (*call)._kind_6.sons->data[((NI) 0)];
	{
		NIM_BOOL T16_;
		NIM_BOOL T18_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* iter;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* hp;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T22_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T23_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T24_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T25_;
		T16_ = (NIM_BOOL)0;
		T16_ = ((*op).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T16_)) goto LA17_;
		T18_ = (NIM_BOOL)0;
		T18_ = ((*(*op)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
		if (!(T18_)) goto LA19_;
		T18_ = ((*(*(*op)._kind_4.sym).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		LA19_: ;
		T16_ = T18_;
		LA17_: ;
		if (!T16_) goto LA20_;
		iter = (*op)._kind_4.sym;
		hp = getHiddenParam__EE7nw3Cq0S1IZY9aGfs1AtA(g, iter);
		env = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 9), (*iter).name, owner, (*body).info, 0);
		asgnRef((void**) (&(*env).typ), (*hp).typ);
		(*env).flags = (*hp).flags;
		v = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99), (*body).info);
		T22_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T22_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(env);
		addVar__qOCBdprWtK4hxer73SEdQA(v, T22_);
		add__P8dDSotTW25BkfbyspojGg(result, v);
		T23_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T23_ = getSysSym__9bvw79ck1FDiWpnBYh88rEfw(g, (*env).info, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_23));
		T24_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T24_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(env);
		T25_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T25_ = newCall__8664d9ayvIMAWB9cM5EcHP7Q(T23_, T24_);
		add__P8dDSotTW25BkfbyspojGg(result, T25_);
		createTypeBoundOpsLL__zNEHc9bDojTsulmL716BbGw(g, (*env).typ, (*body).info, owner);
	}
	goto LA14_;
	LA20_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* closure;
		if (!((*op).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126))) goto LA27_;
		closure = lastSon__UPSW0jLTX5qJL51YMUAHgw(op);
		{
			if (!((*closure).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 155))) goto LA31_;
			asgnRef((void**) (&(*call)._kind_6.sons->data[((NI) 0)]), closure);
			{
				NI i;
				NI colontmp_;
				NI T34_;
				NI i_2;
				i = (NI)0;
				colontmp_ = (NI)0;
				T34_ = (NI)0;
				T34_ = len__P89cqdlERShb9alU3iC0yj8wast(op);
				colontmp_ = (NI)(T34_ - ((NI) 1));
				i_2 = ((NI) 0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA36;
						i = i_2;
						add__P8dDSotTW25BkfbyspojGg(result, (*op)._kind_6.sons->data[i]);
						i_2 += ((NI) 1);
					} LA36: ;
				}
			}
		}
		LA31_: ;
	}
	goto LA14_;
	LA27_: ;
	LA14_: ;
	loopBody = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*body).info, ((NI) 3));
	whileLoop = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 96), (*body).info, ((NI) 2));
	T37_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T37_ = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg(g, (*body).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 1));
	asgnRef((void**) (&(*whileLoop)._kind_6.sons->data[((NI) 0)]), newIntTypeNode__9azVbThnGagKx8BBa5Ph9cDw(IL64(1), T37_));
	asgnRef((void**) (&(*whileLoop)._kind_6.sons->data[((NI) 1)]), loopBody);
	add__P8dDSotTW25BkfbyspojGg(result, whileLoop);
	v2 = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 100), (*body).info);
	T38_ = (tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw)0;
	{
		NI T41_;
		T41_ = (NI)0;
		T41_ = len__P89cqdlERShb9alU3iC0yj8wast(body);
		if (!(T41_ == ((NI) 3))) goto LA42_;
		T38_ = ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35);
	}
	goto LA39_;
	LA42_: ;
	{
		T38_ = ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 36);
	}
	LA39_: ;
	vpart = newNodeI__vokyXY9cZDshCSxFKChhG9bg(T38_, (*body).info);
	{
		NI i_3;
		NI colontmp__2;
		NI T46_;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		T46_ = (NI)0;
		T46_ = len__P89cqdlERShb9alU3iC0yj8wast(body);
		colontmp__2 = (NI)(T46_ - ((NI) 2));
		i_4 = ((NI) 0);
		{
			while (1) {
				if (!(i_4 < colontmp__2)) goto LA48;
				i_3 = i_4;
				{
					if (!((*(*body)._kind_6.sons->data[i_3]).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA51_;
					transitionToLet__EEixHgS5VK63cVXrrMe6Tw_2((*(*body)._kind_6.sons->data[i_3])._kind_4.sym);
				}
				LA51_: ;
				add__P8dDSotTW25BkfbyspojGg(vpart, (*body)._kind_6.sons->data[i_3]);
				i_4 += ((NI) 1);
			} LA48: ;
		}
	}
	T53_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T53_ = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*body).info);
	add__P8dDSotTW25BkfbyspojGg(vpart, T53_);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T58_;
		if (!!((env == 0))) goto LA56_;
		T58_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T58_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(env);
		asgnRef((void**) (&(*call)._kind_6.sons->data[((NI) 0)]), makeClosure__fa9aZDXQ04CAodm0trAX6LA(g, (*(*call)._kind_6.sons->data[((NI) 0)])._kind_4.sym, T58_, (*body).info));
	}
	LA56_: ;
	add__P8dDSotTW25BkfbyspojGg(vpart, call);
	add__P8dDSotTW25BkfbyspojGg(v2, vpart);
	asgnRef((void**) (&(*loopBody)._kind_6.sons->data[((NI) 0)]), v2);
	bs = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 158), (*body).info);
	add__P8dDSotTW25BkfbyspojGg(bs, (*call)._kind_6.sons->data[((NI) 0)]);
	ibs = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 92), (*body).info);
	elifBranch = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 86), (*body).info);
	add__P8dDSotTW25BkfbyspojGg(elifBranch, bs);
	br = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 110), (*body).info);
	add__P8dDSotTW25BkfbyspojGg(br, (*g).emptyNode);
	add__P8dDSotTW25BkfbyspojGg(elifBranch, br);
	add__P8dDSotTW25BkfbyspojGg(ibs, elifBranch);
	asgnRef((void**) (&(*loopBody)._kind_6.sons->data[((NI) 1)]), ibs);
	T59_ = (NI)0;
	T59_ = len__P89cqdlERShb9alU3iC0yj8wast(body);
	asgnRef((void**) (&(*loopBody)._kind_6.sons->data[((NI) 2)]), (*body)._kind_6.sons->data[(NI)(T59_ - ((NI) 1))]);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, freshVarForClosureIter__JA4vA9a9b64Ti9cPXENYI6L5g)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* envParam;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* access;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	envParam = getHiddenParam__EE7nw3Cq0S1IZY9aGfs1AtA(g, owner);
	obj = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*envParam).typ, IL64(35184378380288));
	addField__hrnJBvN8tSy4gj6R5QDcYw(obj, s, (*g).cache);
	access = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(envParam);
	field = getFieldFromObj__a9b9aDcfE1em9bBkDPbo9cqoSg(obj, s);
	{
		if (!!((field == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)))) goto LA3_;
		result = rawIndirectAccess__8aXgrGQvaIrhwp6o9cuBYoA(access, field, (*s).info);
	}
	goto LA1_;
	LA3_: ;
	{
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*s).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_40), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__PI7oJkFuxeeTWjPTjlNxqg_41, NIM_FALSE);
		result = access;
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getClosureIterResult__9coyF0wpG1VqYcJq7Zk1fgQ_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* iter) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__P89cqdlERShb9alU3iC0yj8wast((*iter).ast);
		if (!(((NI) 7) < T3_)) goto LA4_;
		result = (*(*(*iter).ast)._kind_6.sons->data[((NI) 7)])._kind_4.sym;
	}
	goto LA1_;
	LA4_: ;
	{
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T7_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T8_;
		T7_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T7_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*g).cache, ((NimStringDesc*) &TM__PI7oJkFuxeeTWjPTjlNxqg_42));
		result = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 11), T7_, iter, (*iter).info, 0);
		asgnRef((void**) (&(*result).typ), (*(*iter).typ).sons->data[((NI) 0)]);
		(*result).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 0)) & 63);
		T8_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T8_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(result);
		add__P8dDSotTW25BkfbyspojGg((*iter).ast, T8_);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getStateField__UJpIDWVzs220Reaf7HOAmw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T1_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T2_;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = getHiddenParam__EE7nw3Cq0S1IZY9aGfs1AtA(g, owner);
	T2_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
	T2_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*T1_).typ, IL64(35184378380288));
	result = (*(*(*T2_).n)._kind_6.sons->data[((NI) 0)])._kind_4.sym;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, liftIterToProc__t1WUr4lePynddtLnmYOFEQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fn, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ptrType) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ d;
	tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw c;
	tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw oldKind;
	tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA oldCC;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	nimZeroMem((void*)(&d), sizeof(tyObject_DetectionPass__CrsGUD9a6sd4xCGl64gvIdQ));
	initDetectionPass__P5KW8HQhQCFeBR8BnZtcJw(g, fn, (&d));
	nimZeroMem((void*)(&c), sizeof(tyObject_LiftingPass__xciiuOR269bKYtnZXJZ4Npw));
	initLiftingPass__mkHIcVQZdXl9cGPFvTV4ZWA(fn, (&c));
	oldKind = (*fn).kind;
	oldCC = (*(*fn).typ).callConv;
	transitionRoutineSymKind__IAW6i9bfWpSsueZudnBZzHQ(fn, ((tyEnum_TSymKind__uwRDzlpaGW5WJzgBn4R8Eg) 15));
	(*(*fn).typ).callConv = ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9);
	X5BX5Deq___MQp6geYbWilpbmJT3tnncQ((&d.ownerToType), (*fn).Sup.id, ptrType);
	detectCapturedVars__knMMYMrxMvpPAdvZhU1Tjg(body, fn, (&d));
	result = liftCapturedVars__1JM0Ep6665B6crlfoxbCuQ(body, fn, (&d), (&c));
	transitionRoutineSymKind__IAW6i9bfWpSsueZudnBZzHQ(fn, ((tyEnum_TSymKind__uwRDzlpaGW5WJzgBn4R8Eg) (oldKind)));
	(*(*fn).typ).callConv = oldCC;
	return result;
}
